--- title: Sounds id: sounds layout: default.haml author: Henry David Thoreau date: 2018-04-15 chapter: 4 kind: article ---

## Sounds

But while we are confined to books, though the most select and classic, and read only particular written languages, which are themselves but dialects and provincial, we are in danger of forgetting the language which all things and events speak without metaphor, which alone is copious and standard. Much is published, but little printed. The rays which stream through the shutter will be no longer remembered when the shutter is wholly removed. No method nor discipline can supersede the necessity of being forever on the alert. What is a course of history, or philosophy, or poetry, no matter how well selected, or the best society, or the most admirable routine of life, compared with the discipline of looking always at what is to be seen? Will you be a reader, a student merely, or a seer? Read your fate, see what is before you, and walk on into futurity.

I did not read books the first summer; I hoed beans. Nay, I often did better than this. There were times when I could not afford to sacrifice the bloom of the present moment to any work, whether of the head or hands. I love a broad margin to my life. Sometimes, in a summer morning, having taken my accustomed bath, I sat in my sunny doorway from sunrise till noon, rapt in a revery, amidst the pines and hickories and sumachs, in undisturbed solitude and stillness, while the birds sing around or flitted noiseless through the house, until by the sun falling in at my west window, or the noise of some traveller’s wagon on the distant highway, I was reminded of the lapse of time. I grew in those seasons like corn in the night, and they were far better than any work of the hands would have been. They were not time subtracted from my life, but so much over and above my usual allowance. I realized what the Orientals mean by contemplation and the forsaking of works. For the most part, I minded not how the hours went. The day advanced as if to light some work of mine; it was morning, and lo, now it is evening, and nothing memorable is accomplished. Instead of singing like the birds, I silently smiled at my incessant good fortune. As the sparrow had its trill, sitting on the hickory before my door, so had I my chuckle or suppressed warble which he might hear out of my nest. My days were not days of the week, bearing the stamp of any heathen deity, nor were they minced into hours and fretted by the ticking of a clock; for I lived like the Puri Indians, of whom it is said that “for yesterday, to-day, and to-morrow they have only one word, and they express the variety of meaning by pointing backward for yesterday, forward for to-morrow, and overhead for the passing day.” This was sheer idleness to my fellow-townsmen, no doubt; but if the birds and flowers had tried me by their standard, I should not have been found wanting. A man must find his occasions in himself, it is true. The natural day is very calm, and will hardly reprove his indolence.

I had this advantage, at least, in my mode of life, over those who were obliged to look abroad for amusement, to society and the theatre, that my life itself was become my amusement and never ceased to be novel. It was a drama of many scenes and without an end. If we were always indeed getting our living, and regulating our lives according to the last and best mode we had learned, we should never be troubled with ennui. Follow your genius closely enough, and it will not fail to show you a fresh prospect every hour. Housework was a pleasant pastime. When my floor was dirty, I rose early, and, setting all my furniture out of doors on the grass, bed and bedstead making but one budget, dashed water on the floor, and sprinkled white sand from the pond on it, and then with a broom scrubbed it clean and white; and by the time the villagers had broken their fast the morning sun had dried my house sufficiently to allow me to move in again, and my meditations were almost uninterupted. It was pleasant to see my whole household effects out on the grass, making a little pile like a gypsy’s pack, and my three-legged table, from which I did not remove the books and pen and ink, standing amid the pines and hickories. They seemed glad to get out themselves, and as if unwilling to be brought in. I was sometimes tempted to stretch an awning over them and take my seat there. It was worth the while to see the sun shine on these things, and hear the free wind blow on them; so much more interesting most familiar objects look out of doors than in the house. A bird sits on the next bough, life-everlasting grows under the table, and blackberry vines run round its legs; pine cones, chestnut burs, and strawberry leaves are strewn about. It looked as if this was the way these forms came to be transferred to our furniture, to tables, chairs, and bedsteads,—because they once stood in their midst.

My house was on the side of a hill, immediately on the edge of the larger wood, in the midst of a young forest of pitch pines and hickories, and half a dozen rods from the pond, to which a narrow footpath led down the hill. In my front yard grew the strawberry, blackberry, and life-everlasting, johnswort and goldenrod, shrub-oaks and sand-cherry, blueberry and groundnut. Near the end of May, the sand-cherry (Cerasus pumila,) adorned the sides of the path with its delicate flowers arranged in umbels cylindrically about its short stems, which last, in the fall, weighed down with good sized and handsome cherries, fell over in wreaths like rays on every side. I tasted them out of compliment to Nature, though they were scarcely palatable. The sumach (Rhus glabra,) grew luxuriantly about the house, pushing up through the embankment which I had made, and growing five or six feet the first season. Its broad pinnate tropical leaf was pleasant though strange to look on. The large buds, suddenly pushing out late in the spring from dry sticks which had seemed to be dead, developed themselves as by magic into graceful green and tender boughs, an inch in diameter; and sometimes, as I sat at my window, so heedlessly did they grow and tax their weak joints, I heard a fresh and tender bough suddenly fall like a fan to the ground, when there was not a breath of air stirring, broken off by its own weight. In August, the large masses of berries, which, when in flower, had attracted many wild bees, gradually assumed their bright velvety crimson hue, and by their weight again bent down and broke the tender limbs.

As I sit at my window this summer afternoon, hawks are circling about my clearing; the tantivy of wild pigeons, flying by twos and threes athwart my view, or perching restless on the white-pine boughs behind my house, gives a voice to the air; a fishhawk dimples the glassy surface of the pond and brings up a fish; a mink steals out of the marsh before my door and seizes a frog by the shore; the sedge is bending under the weight of the reed-birds flitting hither and thither; and for the last half hour I have heard the rattle of railroad cars, now dying away and then reviving like the beat of a partridge, conveying travellers from Boston to the country. For I did not live so out of the world as that boy who, as I hear, was put out to a farmer in the east part of the town, but ere long ran away and came home again, quite down at the heel and homesick. He had never seen such a dull and out-of-the-way place; the folks were all gone off; why, you couldn’t even hear the whistle! I doubt if there is such a place in Massachusetts now:—

     “In truth, our village has become a butt
     For one of those fleet railroad shafts, and o’er
     Our peaceful plain its soothing sound is—Concord.”

The Fitchburg Railroad touches the pond about a hundred rods south of where I dwell. I usually go to the village along its causeway, and am, as it were, related to society by this link. The men on the freight trains, who go over the whole length of the road, bow to me as to an old acquaintance, they pass me so often, and apparently they take me for an employee; and so I am. I too would fain be a track-repairer somewhere in the orbit of the earth.

The whistle of the locomotive penetrates my woods summer and winter, sounding like the scream of a hawk sailing over some farmer’s yard, informing me that many restless city merchants are arriving within the circle of the town, or adventurous country traders from the other side. As they come under one horizon, they shout their warning to get off the track to the other, heard sometimes through the circles of two towns. Here come your groceries, country; your rations, countrymen! Nor is there any man so independent on his farm that he can say them nay. And here’s your pay for them! screams the countryman’s whistle; timber like long battering rams going twenty miles an hour against the city’s walls, and chairs enough to seat all the weary and heavy laden that dwell within them. With such huge and lumbering civility the country hands a chair to the city. All the Indian huckleberry hills are stripped, all the cranberry meadows are raked into the city. Up comes the cotton, down goes the woven cloth; up comes the silk, down goes the woollen; up come the books, but down goes the wit that writes them.

When I meet the engine with its train of cars moving off with planetary motion,—or, rather, like a comet, for the beholder knows not if with that velocity and with that direction it will ever revisit this system, since its orbit does not look like a returning curve,—with its steam cloud like a banner streaming behind in golden and silver wreaths, like many a downy cloud which I have seen, high in the heavens, unfolding its masses to the light,—as if this travelling demigod, this cloud-compeller, would ere long take the sunset sky for the livery of his train; when I hear the iron horse make the hills echo with his snort like thunder, shaking the earth with his feet, and breathing fire and smoke from his nostrils, (what kind of winged horse or fiery dragon they will put into the new Mythology I don’t know), it seems as if the earth had got a race now worthy to inhabit it. If all were as it seems, and men made the elements their servants for noble ends! If the cloud that hangs over the engine were the perspiration of heroic deeds, or as beneficent as that which floats over the farmer’s fields, then the elements and Nature herself would cheerfully accompany men on their errands and be their escort.

I watch the passage of the morning cars with the same feeling that I do the rising of the sun, which is hardly more regular. Their train of clouds stretching far behind and rising higher and higher, going to heaven while the cars are going to Boston, conceals the sun for a minute and casts my distant field into the shade, a celestial train beside which the petty train of cars which hugs the earth is but the barb of the spear. The stabler of the iron horse was up early this winter morning by the light of the stars amid the mountains, to fodder and harness his steed. Fire, too, was awakened thus early to put the vital heat in him and get him off. If the enterprise were as innocent as it is early! If the snow lies deep, they strap on his snow-shoes, and with the giant plow, plow a furrow from the mountains to the seaboard, in which the cars, like a following drill-barrow, sprinkle all the restless men and floating merchandise in the country for seed. All day the fire-steed flies over the country, stopping only that his master may rest, and I am awakened by his tramp and defiant snort at midnight, when in some remote glen in the woods he fronts the elements incased in ice and snow; and he will reach his stall only with the morning star, to start once more on his travels without rest or slumber. Or perchance, at evening, I hear him in his stable blowing off the superfluous energy of the day, that he may calm his nerves and cool his liver and brain for a few hours of iron slumber. If the enterprise were as heroic and commanding as it is protracted and unwearied!

Far through unfrequented woods on the confines of towns, where once only the hunter penetrated by day, in the darkest night dart these bright saloons without the knowledge of their inhabitants; this moment stopping at some brilliant station-house in town or city, where a social crowd is gathered, the next in the Dismal Swamp, scaring the owl and fox. The startings and arrivals of the cars are now the epochs in the village day. They go and come with such regularity and precision, and their whistle can be heard so far, that the farmers set their clocks by them, and thus one well conducted institution regulates a whole country. Have not men improved somewhat in punctuality since the railroad was invented? Do they not talk and think faster in the depot than they did in the stage-office? There is something electrifying in the atmosphere of the former place. I have been astonished at the miracles it has wrought; that some of my neighbors, who, I should have prophesied, once for all, would never get to Boston by so prompt a conveyance, are on hand when the bell rings. To do things “railroad fashion” is now the by-word; and it is worth the while to be warned so often and so sincerely by any power to get off its track. There is no stopping to read the riot act, no firing over the heads of the mob, in this case. We have constructed a fate, an Atropos, that never turns aside. (Let that be the name of your engine.) Men are advertised that at a certain hour and minute these bolts will be shot toward particular points of the compass; yet it interferes with no man’s business, and the children go to school on the other track. We live the steadier for it. We are all educated thus to be sons of Tell. The air is full of invisible bolts. Every path but your own is the path of fate. Keep on your own track, then.

What recommends commerce to me is its enterprise and bravery. It does not clasp its hands and pray to Jupiter. I see these men every day go about their business with more or less courage and content, doing more even than they suspect, and perchance better employed than they could have consciously devised. I am less affected by their heroism who stood up for half an hour in the front line at Buena Vista, than by the steady and cheerful valor of the men who inhabit the snow-plough for their winter quarters; who have not merely the three-o’-clock in the morning courage, which Bonaparte thought was the rarest, but whose courage does not go to rest so early, who go to sleep only when the storm sleeps or the sinews of their iron steed are frozen. On this morning of the Great Snow, perchance, which is still raging and chilling men’s blood, I hear the muffled tone of their engine bell from out the fog bank of their chilled breath, which announces that the cars are coming, without long delay, notwithstanding the veto of a New England north-east snow storm, and I behold the ploughmen covered with snow and rime, their heads peering, above the mould-board which is turning down other than daisies and the nests of field-mice, like bowlders of the Sierra Nevada, that occupy an outside place in the universe.

Commerce is unexpectedly confident and serene, alert, adventurous, and unwearied. It is very natural in its methods withal, far more so than many fantastic enterprises and sentimental experiments, and hence its singular success. I am refreshed and expanded when the freight train rattles past me, and I smell the stores which go dispensing their odors all the way from Long Wharf to Lake Champlain, reminding me of foreign parts, of coral reefs, and Indian oceans, and tropical climes, and the extent of the globe. I feel more like a citizen of the world at the sight of the palm-leaf which will cover so many flaxen New England heads the next summer, the Manilla hemp and cocoa-nut husks, the old junk, gunny bags, scrap iron, and rusty nails. This car-load of torn sails is more legible and interesting now than if they should be wrought into paper and printed books. Who can write so graphically the history of the storms they have weathered as these rents have done? They are proof-sheets which need no correction. Here goes lumber from the Maine woods, which did not go out to sea in the last freshet, risen four dollars on the thousand because of what did go out or was split up; pine, spruce, cedar,—first, second, third, and fourth qualities, so lately all of one quality, to wave over the bear, and moose, and caribou. Next rolls Thomaston lime, a prime lot, which will get far among the hills before it gets slacked. These rags in bales, of all hues and qualities, the lowest condition to which cotton and linen descend, the final result of dress,—of patterns which are now no longer cried up, unless it be in Milwaukie, as those splendid articles, English, French, or American prints, ginghams, muslins, &c., gathered from all quarters both of fashion and poverty, going to become paper of one color or a few shades only, on which forsooth will be written tales of real life, high and low, and founded on fact! This closed car smells of salt fish, the strong New England and commercial scent, reminding me of the Grand Banks and the fisheries. Who has not seen a salt fish, thoroughly cured for this world, so that nothing can spoil it, and putting the perseverance of the saints to the blush? with which you may sweep or pave the streets, and split your kindlings, and the teamster shelter himself and his lading against sun wind and rain behind it,—and the trader, as a Concord trader once did, hang it up by his door for a sign when he commences business, until at last his oldest customer cannot tell surely whether it be animal, vegetable, or mineral, and yet it shall be as pure as a snowflake, and if it be put into a pot and boiled, will come out an excellent dun fish for a Saturday’s dinner. Next Spanish hides, with the tails still preserving their twist and the angle of elevation they had when the oxen that wore them were careering over the pampas of the Spanish main,—a type of all obstinacy, and evincing how almost hopeless and incurable are all constitutional vices. I confess, that practically speaking, when I have learned a man’s real disposition, I have no hopes of changing it for the better or worse in this state of existence. As the Orientals say, “A cur’s tail may be warmed, and pressed, and bound round with ligatures, and after a twelve years’ labor bestowed upon it, still it will retain its natural form.” The only effectual cure for such inveteracies as these tails exhibit is to make glue of them, which I believe is what is usually done with them, and then they will stay put and stick. Here is a hogshead of molasses or of brandy directed to John Smith, Cuttingsville, Vermont, some trader among the Green Mountains, who imports for the farmers near his clearing, and now perchance stands over his bulk-head and thinks of the last arrivals on the coast, how they may affect the price for him, telling his customers this moment, as he has told them twenty times before this morning, that he expects some by the next train of prime quality. It is advertised in the Cuttingsville Times.

While these things go up other things come down. Warned by the whizzing sound, I look up from my book and see some tall pine, hewn on far northern hills, which has winged its way over the Green Mountains and the Connecticut, shot like an arrow through the township within ten minutes, and scarce another eye beholds it; going

     “to be the mast
     Of some great ammiral.”

And hark! here comes the cattle-train bearing the cattle of a thousand hills, sheepcots, stables, and cow-yards in the air, drovers with their sticks, and shepherd boys in the midst of their flocks, all but the mountain pastures, whirled along like leaves blown from the mountains by the September gales. The air is filled with the bleating of calves and sheep, and the hustling of oxen, as if a pastoral valley were going by. When the old bell-wether at the head rattles his bell, the mountains do indeed skip like rams and the little hills like lambs. A car-load of drovers, too, in the midst, on a level with their droves now, their vocation gone, but still clinging to their useless sticks as their badge of office. But their dogs, where are they? It is a stampede to them; they are quite thrown out; they have lost the scent. Methinks I hear them barking behind the Peterboro’ Hills, or panting up the western slope of the Green Mountains. They will not be in at the death. Their vocation, too, is gone. Their fidelity and sagacity are below par now. They will slink back to their kennels in disgrace, or perchance run wild and strike a league with the wolf and the fox. So is your pastoral life whirled past and away. But the bell rings, and I must get off the track and let the cars go by;—

     What’s the railroad to me?
     I never go to see
     Where it ends.
     It fills a few hollows,
     And makes banks for the swallows,
     It sets the sand a-blowing,
     And the blackberries a-growing,

but I cross it like a cart-path in the woods. I will not have my eyes put out and my ears spoiled by its smoke and steam and hissing.

Now that the cars are gone by and all the restless world with them, and the fishes in the pond no longer feel their rumbling, I am more alone than ever. For the rest of the long afternoon, perhaps, my meditations are interrupted only by the faint rattle of a carriage or team along the distant highway.

Sometimes, on Sundays, I heard the bells, the Lincoln, Acton, Bedford, or Concord bell, when the wind was favorable, a faint, sweet, and, as it were, natural melody, worth importing into the wilderness. At a sufficient distance over the woods this sound acquires a certain vibratory hum, as if the pine needles in the horizon were the strings of a harp which it swept. All sound heard at the greatest possible distance produces one and the same effect, a vibration of the universal lyre, just as the intervening atmosphere makes a distant ridge of earth interesting to our eyes by the azure tint it imparts to it. There came to me in this case a melody which the air had strained, and which had conversed with every leaf and needle of the wood, that portion of the sound which the elements had taken up and modulated and echoed from vale to vale. The echo is, to some extent, an original sound, and therein is the magic and charm of it. It is not merely a repetition of what was worth repeating in the bell, but partly the voice of the wood; the same trivial words and notes sung by a wood-nymph.

At evening, the distant lowing of some cow in the horizon beyond the woods sounded sweet and melodious, and at first I would mistake it for the voices of certain minstrels by whom I was sometimes serenaded, who might be straying over hill and dale; but soon I was not unpleasantly disappointed when it was prolonged into the cheap and natural music of the cow. I do not mean to be satirical, but to express my appreciation of those youths’ singing, when I state that I perceived clearly that it was akin to the music of the cow, and they were at length one articulation of Nature.

Regularly at half past seven, in one part of the summer, after the evening train had gone by, the whippoorwills chanted their vespers for half an hour, sitting on a stump by my door, or upon the ridge pole of the house. They would begin to sing almost with as much precision as a clock, within five minutes of a particular time, referred to the setting of the sun, every evening. I had a rare opportunity to become acquainted with their habits. Sometimes I heard four or five at once in different parts of the wood, by accident one a bar behind another, and so near me that I distinguished not only the cluck after each note, but often that singular buzzing sound like a fly in a spider’s web, only proportionally louder. Sometimes one would circle round and round me in the woods a few feet distant as if tethered by a string, when probably I was near its eggs. They sang at intervals throughout the night, and were again as musical as ever just before and about dawn.

When other birds are still the screech owls take up the strain, like mourning women their ancient u-lu-lu. Their dismal scream is truly Ben Jonsonian. Wise midnight hags! It is no honest and blunt tu-whit tu-who of the poets, but, without jesting, a most solemn graveyard ditty, the mutual consolations of suicide lovers remembering the pangs and the delights of supernal love in the infernal groves. Yet I love to hear their wailing, their doleful responses, trilled along the wood-side; reminding me sometimes of music and singing birds; as if it were the dark and tearful side of music, the regrets and sighs that would fain be sung. They are the spirits, the low spirits and melancholy forebodings, of fallen souls that once in human shape night-walked the earth and did the deeds of darkness, now expiating their sins with their wailing hymns or threnodies in the scenery of their transgressions. They give me a new sense of the variety and capacity of that nature which is our common dwelling. Oh-o-o-o-o that I never had been bor-r-r-r-n! sighs one on this side of the pond, and circles with the restlessness of despair to some new perch on the gray oaks. Then—that I never had been bor-r-r-r-n! echoes another on the farther side with tremulous sincerity, and—bor-r-r-r-n! comes faintly from far in the Lincoln woods.

I was also serenaded by a hooting owl. Near at hand you could fancy it the most melancholy sound in Nature, as if she meant by this to stereotype and make permanent in her choir the dying moans of a human being,—some poor weak relic of mortality who has left hope behind, and howls like an animal, yet with human sobs, on entering the dark valley, made more awful by a certain gurgling melodiousness,—I find myself beginning with the letters gl when I try to imitate it,—expressive of a mind which has reached the gelatinous mildewy stage in the mortification of all healthy and courageous thought. It reminded me of ghouls and idiots and insane howlings. But now one answers from far woods in a strain made really melodious by distance,—Hoo hoo hoo, hoorer hoo; and indeed for the most part it suggested only pleasing associations, whether heard by day or night, summer or winter.

I rejoice that there are owls. Let them do the idiotic and maniacal hooting for men. It is a sound admirably suited to swamps and twilight woods which no day illustrates, suggesting a vast and undeveloped nature which men have not recognized. They represent the stark twilight and unsatisfied thoughts which all have. All day the sun has shone on the surface of some savage swamp, where the single spruce stands hung with usnea lichens, and small hawks circulate above, and the chickadee lisps amid the evergreens, and the partridge and rabbit skulk beneath; but now a more dismal and fitting day dawns, and a different race of creatures awakes to express the meaning of Nature there.

Late in the evening I heard the distant rumbling of wagons over bridges,—a sound heard farther than almost any other at night,—the baying of dogs, and sometimes again the lowing of some disconsolate cow in a distant barn-yard. In the mean while all the shore rang with the trump of bullfrogs, the sturdy spirits of ancient wine-bibbers and wassailers, still unrepentant, trying to sing a catch in their Stygian lake,—if the Walden nymphs will pardon the comparison, for though there are almost no weeds, there are frogs there,—who would fain keep up the hilarious rules of their old festal tables, though their voices have waxed hoarse and solemnly grave, mocking at mirth, and the wine has lost its flavor, and become only liquor to distend their paunches, and sweet intoxication never comes to drown the memory of the past, but mere saturation and waterloggedness and distention. The most aldermanic, with his chin upon a heart-leaf, which serves for a napkin to his drooling chaps, under this northern shore quaffs a deep draught of the once scorned water, and passes round the cup with the ejaculation tr-r-r-oonk, tr-r-r-oonk, tr-r-r-oonk! and straightway comes over the water from some distant cove the same password repeated, where the next in seniority and girth has gulped down to his mark; and when this observance has made the circuit of the shores, then ejaculates the master of ceremonies, with satisfaction, tr-r-r-oonk! and each in his turn repeats the same down to the least distended, leakiest, and flabbiest paunched, that there be no mistake; and then the bowl goes round again and again, until the sun disperses the morning mist, and only the patriarch is not under the pond, but vainly bellowing troonk from time to time, and pausing for a reply.

I am not sure that I ever heard the sound of cock-crowing from my clearing, and I thought that it might be worth the while to keep a cockerel for his music merely, as a singing bird. The note of this once wild Indian pheasant is certainly the most remarkable of any bird’s, and if they could be naturalized without being domesticated, it would soon become the most famous sound in our woods, surpassing the clangor of the goose and the hooting of the owl; and then imagine the cackling of the hens to fill the pauses when their lords’ clarions rested! No wonder that man added this bird to his tame stock,—to say nothing of the eggs and drumsticks. To walk in a winter morning in a wood where these birds abounded, their native woods, and hear the wild cockerels crow on the trees, clear and shrill for miles over the resounding earth, drowning the feebler notes of other birds,—think of it! It would put nations on the alert. Who would not be early to rise, and rise earlier and earlier every successive day of his life, till he became unspeakably healthy, wealthy, and wise? This foreign bird’s note is celebrated by the poets of all countries along with the notes of their native songsters. All climates agree with brave Chanticleer. He is more indigenous even than the natives. His health is ever good, his lungs are sound, his spirits never flag. Even the sailor on the Atlantic and Pacific is awakened by his voice; but its shrill sound never roused me from my slumbers. I kept neither dog, cat, cow, pig, nor hens, so that you would have said there was a deficiency of domestic sounds; neither the churn, nor the spinning wheel, nor even the singing of the kettle, nor the hissing of the urn, nor children crying, to comfort one. An old-fashioned man would have lost his senses or died of ennui before this. Not even rats in the wall, for they were starved out, or rather were never baited in,—only squirrels on the roof and under the floor, a whippoorwill on the ridge pole, a blue-jay screaming beneath the window, a hare or woodchuck under the house, a screech-owl or a cat-owl behind it, a flock of wild geese or a laughing loon on the pond, and a fox to bark in the night. Not even a lark or an oriole, those mild plantation birds, ever visited my clearing. No cockerels to crow nor hens to cackle in the yard. No yard! but unfenced Nature reaching up to your very sills. A young forest growing up under your meadows, and wild sumachs and blackberry vines breaking through into your cellar; sturdy pitch pines rubbing and creaking against the shingles for want of room, their roots reaching quite under the house. Instead of a scuttle or a blind blown off in the gale,—a pine tree snapped off or torn up by the roots behind your house for fuel. Instead of no path to the front-yard gate in the Great Snow,—no gate,—no front-yard,—and no path to the civilized world!